API
===


Core components
---------------

.. automodule:: swyft.lightning.core
  :members:
  :special-members: __len__, __getitem__


Inference networks
------------------

.. automodule:: swyft.lightning.estimators
  :members:
  :special-members: __len__, __getitem__


Simulator definition
--------------------

.. automodule:: swyft.lightning.simulator
  :members:
  :special-members: __len__, __getitem__


Simulation data
---------------

.. automodule:: swyft.lightning.data
  :members:
  :special-members: __len__, __getitem__


Utility functions
-----------------

.. automodule:: swyft.lightning.utils
  :members:
  :special-members: __len__, __getitem__


Truncation bounds
-----------------

.. automodule:: swyft.lightning.bounds
  :members:
  :special-members: __len__, __getitem__


Plotting
--------

.. automodule:: swyft.plot
  :members:
  :special-members: __len__, __getitem__

